# TCS3472

Color Light-to-Digital Converter with IR Filter

- Device address 41
- Address type 7-bit

### Addr 128 8-bytes | # Setup the device configuration ## Enable RGBC and Power ### [7:0] | 8-bytes
### Addr 180 16-bytes Read-only | # Clear channel ## This is the ambient amount of detected light.
### Addr 182 16-bytes Read-only | # Red channel ## Red light as an int. Divide by ambient light to get scaled number.
### Addr 184 16-bytes Read-only | # Green channel ## Green light as an int. Divide by ambient light to get scaled number.
### Addr 186 16-bytes Read-only | # Blue channel ## Blue light as an int. Divide by ambient light to get scaled number.

## Functions

- _lifecycle.Begin - Enables features on device